/* CSLR include files */
#include <stdio.h>
#include "tas2563-baremetal.h"
#include "tas2563-regmap-bypass.h"

#define I2C_TEST_FAILED         (1)
#define I2C_TEST_PASSED         (0)
#define I2C_SPI_MAX_TIMEOUT 	(1000)
#define BURST_MAX 				(100)

#define READ_I2C				(1)
#define WRITE_I2C				(0)

#define CHANNEL_LEFT  0x98
#define CHANNEL_RIGHT 0x9a

uint16 PltI2cTransfer( uint8 address, uint8 * tx, uint16 tx_len, uint8 * rx, uint16 rx_len )
{
 return 0;
}

void delay (long count) {
	long i = 0;
	for(i = 0; i < count; i++)
	{;}
}

uint16 tas2563_write_reg(uint8 SlaveAddr, uint8* regValue, uint16 count)
{
	uint16  retval = 0;
	SlaveAddr = (SlaveAddr << 1) | WRITE_I2C;
	retval = PltI2cTransfer(SlaveAddr, regValue, count, 0, 0);
	if(retval <= 0)
		return (I2C_TEST_FAILED);

	return(retval);
}

uint16 tas2563_read_reg(uint8 SlaveAddr, uint8* regValue, uint16 count) 
{
	uint16  retval = 0;
	SlaveAddr = (SlaveAddr << 1) | READ_I2C;
	retval = PltI2cTransfer(SlaveAddr, 0, 0, regValue, count);
	if(retval <= 0)
		return (I2C_TEST_FAILED);

	return(retval);
}

void tas2563_transmit_registers(uint8 SlaveAddr, cfg_reg *r, int n)
{
        int i = 0;
        while (i < n) {
            switch (r[i].command) {
            case CFG_META_SWITCH:
                // Used in legacy applications.  Ignored here.
                break;
            case CFG_META_DELAY:
                delay(r[i].param);
                break;
            case CFG_META_BURST:
                tas2563_write_reg(SlaveAddr, (unsigned char *)&r[i+1], r[i].param);
                i +=  (r[i].param / 2) + 1;
                break;
            default:
                tas2563_write_reg(SlaveAddr, (unsigned char *)&r[i], 1);
                break;
            }
            i++;
        }
}

void tas2563_config_registers(uint8 SlaveAddr, uint8 id)
{
	if(id == 1)
		tas2563_transmit_registers(SlaveAddr, power_down_reset, sizeof(power_down_reset)/(sizeof(cfg_u8)*2));
	if(id == 2)
		tas2563_transmit_registers(SlaveAddr, program, sizeof(program)/(sizeof(cfg_u8)*2));
	if(id == 3)
		tas2563_transmit_registers(SlaveAddr, configuration, sizeof(configuration)/(sizeof(cfg_u8)*2));
	if(id == 4)
		tas2563_transmit_registers(SlaveAddr, powerup, sizeof(powerup)/(sizeof(cfg_u8)*2));
	if(id == 5)
		tas2563_transmit_registers(SlaveAddr, unmute, sizeof(unmute)/(sizeof(cfg_u8)*2));
#if 0
	if(id == 2) // tas2563 can not set pll 
		tas2563_transmit_registers(SlaveAddr, pll, sizeof(pll)/(sizeof(cfg_u8)*2));
#endif
}

int main(int argc, const char *argv[])
{
	int id = 0;
	for (id = 1 ; id < 5; id++)
		tas2563_config_registers(CHANNEL_LEFT, id);
	return 0;
}
